import java.awt.*;
import java.applet.*;
import java.io.*;
import java.util.*;

public class TestAppletCodebaseOne1 extends Applet
{
  public String getName ()
  {
    return "applet 1 in codebase 1";
  }

  public void init () throws java.io.IOException
  {
    System.out.println ("TestAppletCodebaseOne1.init");

    AppletContext ac = getAppletContext ();

    if (ac == null)
      {
	System.err.println ("error: applet context of " + getName () + " is null");
	return;
      }

    ac.setStream (getName () + " stream 1", new PipedInputStream ());
    ac.setStream (getName () + " stream 2", new PipedInputStream ());
    ac.setStream (getName () + " stream 3", new PipedInputStream ());
    ac.setStream (getName () + " stream 4", new PipedInputStream ());
  }

  public void start ()
  {
    System.out.println ("TestAppletCodebaseOne1.start");
    System.out.println ("codebase one 1 applet current keyboard manager: " + KeyboardFocusManager.getCurrentKeyboardFocusManager ());
    System.out.println ("codebase one 1 applet context: " + getAppletContext ());
    System.out.println ("codebase one 1 thread group: " + Thread.currentThread ().getThreadGroup ());
  }
}
